@@ -204,17 +204,41 @@ VALID_PARAMETER_TYPES = VALID_PARAMETER_TYPES_SINGLE + VALID_PARAMETER_TYPES_LIS
 class RegexDict(dict):
 
     def __getitem__(self, item):
-        for k, v in self.items():
-            if re.match(k, item):
-                return v
-        raise KeyError
+        possible_items = {}
+        for k, v  in self.items():
+            if isinstance(v, dict):
+                if v.get('Type') == 'MODULE':
+                    if re.match(k, item):
+                        possible_items[k] = v
+                else:
+                    if k == item:
+                        possible_items[k] = v
+            elif re.match(k, item):
+                possible_items[k] = v
+        if not possible_items:
+            raise KeyError
+        longest_match = sorted(possible_items.keys(), key=len)[-1]
+        return possible_items[longest_match]
 
     def __contains__(self, item):
-        for k in self.keys():
-            if re.match(k, item):
+        for k, v in self.items():
+            if isinstance(v, dict):
+                if v.get('Type') == 'MODULE':
+                    if re.match(k, item):
+                        return True
+                else:
+                    if k == item:
+                        return True
+            elif re.match(k, item):
                 return True
         return False
 
+    def get(self, key, default=None):
+        try:
+            return self[key]
+        except KeyError:
+            return default
+
 def get_metadata_filename(url):
     """Returns the filename for a metadata file associated with a remote resource"""
     caching_dir = os.path.join(os.path.dirname(__file__), 'data', 'DownloadsMetadata')
@@ -312,7 +336,7 @@ def load_resource(package, filename='us-east-1.json'):
 
 
 RESOURCE_SPECS = {}
-
+REGISTRY_SCHEMAS = []
 
 def merge_spec(source, destination):
     """ Recursive merge spec dict """
@@ -415,6 +439,8 @@ def create_rules(mod):
     from the given module."""
     result = []
     for _, clazz in inspect.getmembers(mod, inspect.isclass):
+        if clazz.__name__ == 'CustomRule' and clazz.__module__ == 'cfnlint.rules.custom':
+            continue
         method_resolution = inspect.getmro(clazz)
         if [clz for clz in method_resolution[1:] if clz.__module__ in ('cfnlint', 'cfnlint.rules') and clz.__name__ == 'CloudFormationLintRule']:
             # create and instance of subclasses of CloudFormationLintRule
